@@ -6,7 +6,7 @@ from time import sleep
 from notification.models import TaskHistory
 from dbaas_aclapi import helpers
 from dbaas_aclapi.acl_base_client import get_acl_client
-from acl_base_client import STATUS_PENDING, STATUS_ERROR
+from acl_base_client import STATUS_PENDING, STATUS_ERROR, STATUS_APPLIED
 
 logging.basicConfig()
 LOG = logging.getLogger("AclTask")
@@ -52,7 +52,10 @@ def replicate_acl_for(database, old_ip, new_ip, old_sa=None, new_sa=None):
             if is_ip(search):
                 search = "%s/32" % search
 
-            for rule in helpers.iter_on_acl_rules(acl, {"destination": search}):
+            filter_params = {"destination": search, "status": STATUS_APPLIED} if acl.is_libera_3 \
+                else {"destination": search}
+
+            for rule in helpers.iter_on_acl_rules(acl, filter_params):
                 try:
                     copy_acl_rule(rule, destinations[d], acl,
                                   database, new_sa)
